==> kubernetes-model-4.5.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/runtime/RawExtensionBuilder.java <==
package io.fabric8.kubernetes.api.model.runtime;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RawExtensionBuilder extends RawExtensionFluentImpl<RawExtensionBuilder> implements VisitableBuilder<RawExtension,RawExtensionBuilder>{

    RawExtensionFluent<?> fluent;
    Boolean validationEnabled;

    public RawExtensionBuilder(){
            this(true);
    }
    public RawExtensionBuilder(Boolean validationEnabled){
            this(new RawExtension(), validationEnabled);
    }
    public RawExtensionBuilder(RawExtensionFluent<?> fluent){
            this(fluent, true);
    }
    public RawExtensionBuilder(RawExtensionFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new RawExtension(), validationEnabled);
    }
    public RawExtensionBuilder(RawExtensionFluent<?> fluent,RawExtension instance){
            this(fluent, instance, true);
    }
    public RawExtensionBuilder(RawExtensionFluent<?> fluent,RawExtension instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withRaw(instance.getRaw()); 
            this.validationEnabled = validationEnabled; 
    }
    public RawExtensionBuilder(RawExtension instance){
            this(instance,true);
    }
    public RawExtensionBuilder(RawExtension instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withRaw(instance.getRaw()); 
            this.validationEnabled = validationEnabled; 
    }

    public RawExtension build(){
            RawExtension buildable = new RawExtension(fluent.getRaw());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            RawExtensionBuilder that = (RawExtensionBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-4.9.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/runtime/RawExtensionBuilder.java <==
package io.fabric8.kubernetes.api.model.runtime;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RawExtensionBuilder extends RawExtensionFluentImpl<RawExtensionBuilder> implements VisitableBuilder<RawExtension,RawExtensionBuilder>{

    RawExtensionFluent<?> fluent;
    Boolean validationEnabled;

    public RawExtensionBuilder(){
            this(true);
    }
    public RawExtensionBuilder(Boolean validationEnabled){
            this(new RawExtension(), validationEnabled);
    }
    public RawExtensionBuilder(RawExtensionFluent<?> fluent){
            this(fluent, true);
    }
    public RawExtensionBuilder(RawExtensionFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new RawExtension(), validationEnabled);
    }
    public RawExtensionBuilder(RawExtensionFluent<?> fluent,RawExtension instance){
            this(fluent, instance, true);
    }
    public RawExtensionBuilder(RawExtensionFluent<?> fluent,RawExtension instance,Boolean validationEnabled){
            this.fluent = fluent; 
            this.validationEnabled = validationEnabled; 
    }
    public RawExtensionBuilder(RawExtension instance){
            this(instance,true);
    }
    public RawExtensionBuilder(RawExtension instance,Boolean validationEnabled){
            this.fluent = this; 
            this.validationEnabled = validationEnabled; 
    }

    public RawExtension build(){
            RawExtension buildable = new RawExtension();
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            RawExtensionBuilder that = (RawExtensionBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
